@@ -52,6 +52,7 @@ API Reference
 import logging
 from abc import ABC, abstractmethod
 from numbers import Real
+from typing import TYPE_CHECKING, Any, List, Optional, Tuple, Union
 
 import numpy as np
 import xrayutilities as xu
@@ -62,6 +63,9 @@ from bcdi.graph import graph_utils as gu
 from bcdi.utils import utilities as util
 from bcdi.utils import validation as valid
 
+if TYPE_CHECKING:
+    from bcdi.experiment.setup import Setup
+
 module_logger = logging.getLogger(__name__)
 
 
@@ -70,6 +74,10 @@ class Beamline(ABC):
     Base class for defining a beamline.
 
     :param name: name of the beamline
+    :param sample_offsets: list or tuple of angles in degrees, corresponding to
+     the offsets of each of the sample circles (the offset for the most outer circle
+     should be at index 0). The number of circles is beamline dependent. Convention:
+     the sample offsets will be subtracted to measurement the motor values.
     :param kwargs:
 
      - optional beamline-dependent parameters
@@ -84,19 +92,18 @@ class Beamline(ABC):
     # "x-" detector horizontal axis inboard, as it should be in the CXI convention
     # "y-" detector vertical axis down, as it should be in the CXI convention
 
-    def __init__(self, name, **kwargs):
+    def __init__(self, name, sample_offsets=None, **kwargs):
         self.logger = kwargs.get("logger", module_logger)
         self.name = name
         self.diffractometer = DiffractometerFactory().create_diffractometer(
-            name=name, **kwargs
+            name=name, sample_offsets=sample_offsets, **kwargs
         )
-        loader_kwargs = {"logger": self.logger} if kwargs.get("logger") else {}
         self.loader = create_loader(
             name=name,
             sample_offsets=self.diffractometer.sample_offsets,
-            **loader_kwargs,
+            **kwargs,
         )
-        self.sample_angles = None
+        self.sample_angles: Optional[Tuple[Union[float, List, np.ndarray]]] = None
 
     @property
     @abstractmethod
@@ -140,7 +147,7 @@ class Beamline(ABC):
         """
         Send all sample circles to zero degrees.
 
-        Arrays are rotatedsuch that all circles of the sample stage are at their zero
+        Arrays are rotated such that all circles of the sample stage are at their zero
         position.
 
         :param arrays: tuple of 3D real arrays of the same shape.
@@ -267,9 +274,14 @@ class Beamline(ABC):
          grazing incidence angles are the positions of circles below the rocking circle.
         """
 
-    @staticmethod
     @abstractmethod
-    def process_positions(setup, nb_frames, scan_number, frames_logical=None):
+    def process_positions(
+        self,
+        setup: "Setup",
+        nb_frames: int,
+        scan_number: int,
+        frames_logical: Optional[np.ndarray] = None,
+    ) -> Any:
         """
         Load and crop/pad motor positions depending on the current number of frames.
 
@@ -371,7 +383,7 @@ class BeamlineGoniometer(Beamline):
 
     def __init__(self, name, **kwargs):
         super().__init__(name, **kwargs)
-        self.detector_angles = None
+        self.detector_angles: Optional[Tuple[Union[float, List, np.ndarray]]] = None
 
     @property
     def detector_angles(self):
@@ -389,7 +401,9 @@ class BeamlineGoniometer(Beamline):
         )
         self._detector_angles = value
 
-    def exit_wavevector(self, wavelength, inplane_angle, outofplane_angle):
+    def exit_wavevector(
+        self, wavelength: float, inplane_angle: float, outofplane_angle: float
+    ) -> np.ndarray:
         """
         Calculate the exit wavevector kout.
 
@@ -404,7 +418,9 @@ class BeamlineGoniometer(Beamline):
         # look for the index of the inplane detector circle
         index = self.find_inplane()
 
-        factor = self.orientation_lookup[self.diffractometer.detector_circles[index]]
+        factor: int = self.orientation_lookup[
+            self.diffractometer.detector_circles[index]
+        ]
 
         kout = (
             2
@@ -424,7 +440,7 @@ class BeamlineGoniometer(Beamline):
         )
         return kout
 
-    def find_inplane(self):
+    def find_inplane(self) -> int:
         """
         Find the index of the detector inplane circle.
 
@@ -438,6 +454,8 @@ class BeamlineGoniometer(Beamline):
         for idx, val in enumerate(self.diffractometer.detector_circles):
             if val.startswith("y"):
                 index = idx
+        if index is None:
+            raise ValueError("detector inplane circle not found")
         return index
 
     def find_outofplane(self):
