@@ -7,25 +7,25 @@
 #         Jerome Carnis, carnis_jerome@yahoo.fr
 """Functions related to facet recognition of nanocrystals."""
 
+import sys
+from numbers import Real
+
+import numpy as np
+from matplotlib import patches
+from matplotlib import pyplot as plt
+from scipy import ndimage, stats
+from scipy.interpolate import RegularGridInterpolator, griddata
 from scipy.ndimage.measurements import center_of_mass
 from scipy.signal import convolve
-from scipy.interpolate import RegularGridInterpolator
-from scipy.interpolate import griddata
-from scipy import stats
-from scipy import ndimage
 from skimage.feature import corner_peaks
-from skimage.morphology import watershed
-from numbers import Real
-import numpy as np
-from matplotlib import pyplot as plt
-from matplotlib import patches
-import sys
+from skimage.segmentation import watershed
+
 from bcdi.graph import graph_utils as gu
+from bcdi.graph.colormap import ColormapFactory
 from bcdi.utils import utilities as util
 from bcdi.utils import validation as valid
 
-colormap = gu.Colormap()
-default_cmap = colormap.cmap
+default_cmap = ColormapFactory().cmap
 
 
 def calc_stereoproj_facet(projection_axis, vectors, radius_mean, stereo_center):
