@@ -11,6 +11,7 @@ import gc
 import logging
 from math import pi
 from numbers import Number, Real
+from typing import List, Optional, Tuple, Union
 
 import matplotlib.pyplot as plt
 import numpy as np
@@ -18,7 +19,7 @@ import numpy.ma as ma
 import scipy
 from numpy.fft import fftn, fftshift, ifftn, ifftshift
 from scipy.interpolate import RegularGridInterpolator
-from scipy.ndimage.measurements import center_of_mass
+from scipy.ndimage import center_of_mass
 from scipy.signal import convolve
 from scipy.stats import multivariate_normal, norm
 from skimage.restoration import unwrap_phase
@@ -30,6 +31,10 @@ from ..utils import validation as valid
 module_logger = logging.getLogger(__name__)
 
 
+class ModulusBelowThreshold(Exception):
+    """Custom exception when there are no voxels above a threshold in an array."""
+
+
 def apodize(amp, phase, initial_shape, window_type, debugging=False, **kwargs):
     """
     Apodize the complex array based on the window of the same shape.
@@ -576,15 +581,15 @@ def filter_3d(
 
 
 def find_bulk(
-    amp,
-    support_threshold,
-    method="threshold",
-    width_z=None,
-    width_y=None,
-    width_x=None,
-    debugging=False,
+    amp: np.ndarray,
+    support_threshold: float,
+    method: str = "threshold",
+    width_z: Optional[int] = None,
+    width_y: Optional[int] = None,
+    width_x: Optional[int] = None,
+    debugging: bool = False,
     **kwargs,
-):
+) -> np.ndarray:
     """
     Isolate the inner part of the crystal from the non-physical surface.
 
@@ -708,133 +713,66 @@ def find_bulk(
     return support
 
 
-def find_crop_center(array_shape, crop_shape, pivot):
-    """
-    Find the position of the center of the cropping window.
-
-    It finds the closest voxel to pivot which allows to crop an array of array_shape to
-    crop_shape.
-
-    :param array_shape: initial shape of the array
-    :type array_shape: tuple
-    :param crop_shape: final shape of the array
-    :type crop_shape: tuple
-    :param pivot: position on which the final region of interest dhould be centered
-     (center of mass of the Bragg peak)
-    :type pivot: tuple
-    :return: the voxel position closest to pivot which allows cropping to the defined
-     shape.
-    """
-    valid.valid_container(
-        array_shape,
-        container_types=(tuple, list, np.ndarray),
-        min_length=1,
-        item_types=int,
-        name="array_shape",
-    )
-    ndim = len(array_shape)
-    valid.valid_container(
-        crop_shape,
-        container_types=(tuple, list, np.ndarray),
-        length=ndim,
-        item_types=int,
-        name="crop_shape",
-    )
-    valid.valid_container(
-        pivot,
-        container_types=(tuple, list, np.ndarray),
-        length=ndim,
-        item_types=int,
-        name="pivot",
-    )
-    crop_center = np.empty(ndim)
-    for idx, _ in enumerate(range(ndim)):
-        if max(0, pivot[idx] - crop_shape[idx] // 2) == 0:
-            # not enough range on this side of the com
-            crop_center[idx] = crop_shape[idx] // 2
-        else:
-            if (
-                min(array_shape[idx], pivot[idx] + crop_shape[idx] // 2)
-                == array_shape[idx]
-            ):
-                # not enough range on this side of the com
-                crop_center[idx] = array_shape[idx] - crop_shape[idx] // 2
-            else:
-                crop_center[idx] = pivot[idx]
-
-    crop_center = list(map(int, crop_center))
-    return crop_center
-
-
-def find_datarange(array, plot_margin=10, amplitude_threshold=0.1, keep_size=False):
+def find_datarange(
+    array: np.ndarray,
+    plot_margin: Union[int, List[int]] = 10,
+    amplitude_threshold: float = 0.1,
+    keep_size: bool = False,
+) -> List[int]:
     """
     Find the range where data is larger than a threshold.
 
     It finds the meaningful range of the array where it is larger than the threshold, in
-    order to reduce the memory consumption in latter processing. The range can be
-    larger than the initial data size, which then will need to be padded.
+    order to later crop the array to that shape and reduce the memory consumption in
+    processing. The range can be larger than the initial data size, which then will need
+    to be padded.
 
-    :param array: the complex 3D reconstruction
-    :param plot_margin: user-defined margin to add to the minimum range of the data
+    :param array: a non-empty numpy array
+    :param plot_margin: user-defined margin to add on each side of the thresholded array
     :param amplitude_threshold: threshold used to define a support from the amplitude
     :param keep_size: set to True in order to keep the dataset full size
-    :return:
-     - zrange: half size of the data range to use in the first axis (Z)
-     - yrange: half size of the data range to use in the second axis (Y)
-     - xrange: half size of the data range to use in the third axis (X)
-
+    :return: a list of the ranges (centered in the middle of the array) to use in each
+     dimension.
     """
-    #########################
-    # check some parameters #
-    #########################
-    valid.valid_ndarray(arrays=array, ndim=3)
-    if isinstance(plot_margin, Number):
-        plot_margin = (plot_margin,) * 3
-    valid.valid_container(
-        plot_margin,
-        container_types=(tuple, list, np.ndarray),
-        length=3,
-        item_types=int,
-        name="plot_margin",
-    )
-    valid.valid_item(
-        amplitude_threshold,
-        allowed_types=Real,
-        min_included=0,
-        name="amplitude_threshold",
-    )
+    if array.ndim == 0:
+        raise ValueError("Empty array provided.")
+    if isinstance(plot_margin, int):
+        plot_margin = [plot_margin] * array.ndim
+    if not isinstance(plot_margin, list):
+        raise TypeError(
+            f"Expected 'plot_margin' to be a list, got {type(plot_margin)} "
+        )
+    if len(plot_margin) != array.ndim:
+        raise ValueError(
+            f"'plot_margin' should be of lenght {array.ndim}, got {len(plot_margin)}"
+        )
 
-    #########################################################
-    # find the relevant range where the support is non-zero #
-    #########################################################
-    nbz, nby, nbx = array.shape
     if keep_size:
-        return nbz // 2, nby // 2, nbx // 2
-    support = np.zeros((nbz, nby, nbx))
+        return [int(val) for val in array.shape]
+
+    support = np.zeros(array.shape)
     support[abs(array) > amplitude_threshold * abs(array).max()] = 1
-
-    z, y, x = np.meshgrid(
-        np.arange(0, nbz, 1), np.arange(0, nby, 1), np.arange(0, nbx, 1), indexing="ij"
-    )
-    z = z * support
-    min_z = min(int(np.min(z[np.nonzero(z)])), nbz - int(np.max(z[np.nonzero(z)])))
-
-    y = y * support
-    min_y = min(int(np.min(y[np.nonzero(y)])), nby - int(np.max(y[np.nonzero(y)])))
-
-    x = x * support
-    min_x = min(int(np.min(x[np.nonzero(x)])), nbx - int(np.max(x[np.nonzero(x)])))
-
-    zrange = nbz // 2 - min_z
-    yrange = nby // 2 - min_y
-    xrange = nbx // 2 - min_x
-
-    if plot_margin is not None:
-        zrange += plot_margin[0]
-        yrange += plot_margin[1]
-        xrange += plot_margin[2]
-
-    return zrange, yrange, xrange
+    non_zero_indices = np.nonzero(support)
+    min_half_width_per_axis: List[int] = []
+    try:
+        for idx, nb_elements in enumerate(array.shape):
+            min_half_width_per_axis.append(
+                min(
+                    min(non_zero_indices[idx]),
+                    nb_elements - 1 - max(non_zero_indices[idx]),
+                )
+            )
+    except ValueError as e:
+        raise ModulusBelowThreshold(
+            f"No voxel above the provided threshold {amplitude_threshold}"
+        ) from e
+    return [
+        int(
+            (nb_elements // 2 - min_half_width_per_axis[idx] + plot_margin[idx]) * 2
+            + nb_elements % 2
+        )
+        for idx, nb_elements in enumerate(array.shape)
+    ]
 
 
 def flip_reconstruction(obj, debugging=False, **kwargs):
@@ -920,7 +858,14 @@ def gaussian_kernel(ndim, kernel_length=21, sigma=3, debugging=False):
     return kernel
 
 
-def get_opticalpath(support, direction, k, voxel_size=None, debugging=False, **kwargs):
+def get_opticalpath(
+    support: np.ndarray,
+    direction: str,
+    k: np.ndarray,
+    voxel_size: Optional[Union[float, Tuple[float, float, float]]] = None,
+    debugging: bool = False,
+    **kwargs,
+) -> np.ndarray:
     """
     Calculate the optical path for refraction/absorption corrections in the crystal.
 
@@ -986,7 +931,7 @@ def get_opticalpath(support, direction, k, voxel_size=None, debugging=False, **k
     valid.valid_ndarray(arrays=support, ndim=3)
 
     voxel_size = voxel_size or (1, 1, 1)
-    if isinstance(voxel_size, Number):
+    if isinstance(voxel_size, (float, int)):
         voxel_size = (voxel_size,) * 3
     valid.valid_container(
         voxel_size,
@@ -1001,7 +946,7 @@ def get_opticalpath(support, direction, k, voxel_size=None, debugging=False, **k
     # correct k for the different voxel size in each dimension #
     # (k is expressed in an orthonormal basis)                 #
     ############################################################
-    k = [k[i] * voxel_size[i] for i in range(3)]
+    rescaled_k = [k[i] * voxel_size[i] for i in range(3)]
 
     ###################################################################
     # find the extent of the object, to optimize the calculation time #
@@ -1020,9 +965,11 @@ def get_opticalpath(support, direction, k, voxel_size=None, debugging=False, **k
     # normalize k, now it is in units of voxels #
     #############################################
     if direction == "in":
-        k_norm = -1 / np.linalg.norm(k) * np.asarray(k)  # we will work with -k_in
+        k_norm = (
+            -1 / np.linalg.norm(rescaled_k) * np.asarray(rescaled_k)
+        )  # we will work with -k_in
     else:  # "out"
-        k_norm = 1 / np.linalg.norm(k) * np.asarray(k)
+        k_norm = 1 / np.linalg.norm(rescaled_k) * np.asarray(rescaled_k)
 
     #############################################
     # calculate the optical path for each voxel #
@@ -1749,7 +1696,7 @@ def remove_ramp(
             plt.title("centered np.log10(abs(my_fft).sum(axis=0))")
             plt.pause(0.1)
 
-        logger(f"COM after subpixel shift: {center_of_mass(abs(my_fft) ** 4)}")
+        logger.info(f"COM after subpixel shift: {center_of_mass(abs(my_fft) ** 4)}")
         myobj = fftshift(ifftn(ifftshift(my_fft)))
         del my_fft
         gc.collect()
@@ -2074,7 +2021,7 @@ def remove_ramp_2d(
 
 def sort_reconstruction(
     file_path, data_range, amplitude_threshold, sort_method="variance/mean"
-):
+) -> List[int]:
     """
     Sort out reconstructions based on the metric 'sort_method'.
 
@@ -2165,7 +2112,7 @@ def sort_reconstruction(
     print(quality_array)
     print("sorted list", sorted_obj)
 
-    return sorted_obj
+    return [int(val) for val in sorted_obj]
 
 
 def tukey_window(shape, alpha=np.array([0.5, 0.5, 0.5])):
@@ -2192,20 +2139,22 @@ def tukey_window(shape, alpha=np.array([0.5, 0.5, 0.5])):
 
 
 def unwrap(
-    obj, support_threshold, seed=0, skip_unwrap: bool = False, debugging=True, **kwargs
-):
+    obj: np.ndarray,
+    support_threshold: float,
+    seed: int = 0,
+    debugging: bool = True,
+    **kwargs,
+) -> Tuple[np.ndarray, float]:
     """
     Unwrap the phase of a complex object.
 
     It is based on skimage.restoration.unwrap_phase. A mask can be applied by
     thresholding the modulus of the object.
 
-    :param obj: number or array to be wrapped
+    :param obj: array to be unwrapped
     :param support_threshold: relative threshold used to define a support from abs(obj)
     :param seed: int, random seed. Use always the same value if you want a
      deterministic behavior.
-    :param skip_unwrap: True to apply only the support_threshold to the phase but skip
-     the unwrapping part.
     :param debugging: set to True to see plots
     :param kwargs:
 
@@ -2237,28 +2186,23 @@ def unwrap(
     # 0 is a valid entry for ma.masked_array
     phase_wrapped: np.ndarray = ma.masked_array(np.angle(obj), mask=unwrap_support)
 
-    plot_title = "applying support threshold\n" if skip_unwrap else "unwrapping"
     if debugging and ndim == 3:
         gu.multislices_plot(
             phase_wrapped.data,
             plot_colorbar=True,
-            title=f"Before {plot_title}",
+            title="Before unwrapping",
             reciprocal_space=reciprocal_space,
             is_orthogonal=is_orthogonal,
             cmap=kwargs.get("cmap", "turbo"),
         )
 
-    if skip_unwrap:
-        phase_unwrapped = phase_wrapped
-    else:
-        phase_unwrapped = unwrap_phase(phase_wrapped, wrap_around=False, seed=seed).data
-
+    phase_unwrapped = unwrap_phase(phase_wrapped, wrap_around=False, seed=seed).data
     phase_unwrapped[np.nonzero(unwrap_support)] = 0
     if debugging and ndim == 3:
         gu.multislices_plot(
             phase_unwrapped,
             plot_colorbar=True,
-            title=f"After {plot_title}",
+            title="After unwrapping",
             reciprocal_space=reciprocal_space,
             is_orthogonal=is_orthogonal,
             cmap=kwargs.get("cmap", "turbo"),
