@@ -51,7 +51,10 @@ class CustomEncoder(json.JSONEncoder):
         return json.JSONEncoder.default(self, obj)
 
 
-def apply_logical_array(arrays, frames_logical):
+def apply_logical_array(
+    arrays: Union[np.ndarray, Tuple[np.ndarray, ...]],
+    frames_logical: Optional[np.ndarray],
+) -> Union[np.ndarray, Tuple[np.ndarray, ...]]:
     """
     Apply a logical array to a sequence of arrays.
 
@@ -64,11 +67,10 @@ def apply_logical_array(arrays, frames_logical):
      (added) frame
     :return: an array (if a single array was provided) or a tuple of cropped arrays
     """
-    if frames_logical is None:
-        return arrays
-
     if isinstance(arrays, np.ndarray):
         arrays = (arrays,)
+    if frames_logical is None:
+        return arrays
     valid.valid_1d_array(
         frames_logical,
         allowed_types=Integral,
@@ -80,7 +82,7 @@ def apply_logical_array(arrays, frames_logical):
     # number of measured frames during the experiment
     # frames_logical[idx]=-1 means that a frame was added (padding) at index idx
     original_frames = frames_logical[frames_logical != -1]
-    nb_original = int(original_frames.sum())
+    nb_original = len(original_frames)
 
     output = []
     for array in arrays:
@@ -93,8 +95,8 @@ def apply_logical_array(arrays, frames_logical):
             output.append(array[original_frames != 0])
 
     if len(arrays) == 1:
-        output = output[0]  # return the array instead of the tuple
-    return output
+        return np.asarray(output[0])  # return the array instead of the tuple
+    return tuple(output)
 
 
 def bin_data(array, binning, debugging=False, **kwargs):
@@ -176,7 +178,9 @@ def bin_data(array, binning, debugging=False, **kwargs):
     return newarray
 
 
-def bin_parameters(binning, nb_frames, params, debugging=True):
+def bin_parameters(
+    binning: int, nb_frames: int, params: List[Any], debugging: bool = True
+) -> List[Any]:
     """
     Bin some parameters.
 
@@ -569,6 +573,64 @@ def dos2unix(input_file: str, savedir: str) -> None:
             output.write(row + str.encode("\n"))
 
 
+def find_crop_center(array_shape, crop_shape, pivot):
+    """
+    Find the position of the center of the cropping window.
+
+    It finds the closest voxel to pivot which allows to crop an array of array_shape to
+    crop_shape.
+
+    :param array_shape: initial shape of the array
+    :type array_shape: tuple
+    :param crop_shape: final shape of the array
+    :type crop_shape: tuple
+    :param pivot: position on which the final region of interest dhould be centered
+     (center of mass of the Bragg peak)
+    :type pivot: tuple
+    :return: the voxel position closest to pivot which allows cropping to the defined
+     shape.
+    """
+    valid.valid_container(
+        array_shape,
+        container_types=(tuple, list, np.ndarray),
+        min_length=1,
+        item_types=int,
+        name="array_shape",
+    )
+    ndim = len(array_shape)
+    valid.valid_container(
+        crop_shape,
+        container_types=(tuple, list, np.ndarray),
+        length=ndim,
+        item_types=int,
+        name="crop_shape",
+    )
+    valid.valid_container(
+        pivot,
+        container_types=(tuple, list, np.ndarray),
+        length=ndim,
+        item_types=int,
+        name="pivot",
+    )
+    crop_center = np.empty(ndim)
+    for idx, _ in enumerate(range(ndim)):
+        if max(0, pivot[idx] - crop_shape[idx] // 2) == 0:
+            # not enough range on this side of the com
+            crop_center[idx] = crop_shape[idx] // 2
+        else:
+            if (
+                min(array_shape[idx], pivot[idx] + crop_shape[idx] // 2)
+                == array_shape[idx]
+            ):
+                # not enough range on this side of the com
+                crop_center[idx] = array_shape[idx] - crop_shape[idx] // 2
+            else:
+                crop_center[idx] = pivot[idx]
+
+    crop_center = list(map(int, crop_center))
+    return crop_center
+
+
 def find_file(filename: Optional[str], default_folder: str, **kwargs) -> str:
     """
     Locate a file.
@@ -769,36 +831,48 @@ def create_repr(obj: Any, cls: type) -> str:
     for _, param in enumerate(
         signature(cls.__init__).parameters.keys()  # type: ignore
     ):
-        quote_mark = True
         if param not in ["self", "args", "kwargs"]:
-            value = getattr(obj, param)
-            if isinstance(value, np.ndarray):
-                value = ndarray_to_list(value)
-            if callable(value):
-                value = value.__module__ + "." + value.__name__
-                # it's a string but we don't want to put it in quote mark in order to
-                # be able to call it directly
-                quote_mark = False
-            output += format_repr(param, value, quote_mark=quote_mark)
+            out, quote_mark = format_value(getattr(obj, param))
+            output += f"{param}=" + format_repr(out, quote_mark)
 
     output += ")"
     return str(output)
 
 
-def format_repr(field: str, value: Optional[Any], quote_mark: bool = True) -> str:
+def format_value(value: Any) -> Tuple[Any, bool]:
+    """Format the value for a proper representation."""
+    quote_mark = True
+    if isinstance(value, np.ndarray):
+        out = ndarray_to_list(value)
+        quote_mark = True
+    elif callable(value):
+        out = value.__module__ + "." + value.__name__
+        # it's a string, but we don't want to put it in quote mark in order to
+        # be able to call it directly
+        quote_mark = False
+    elif isinstance(value, dict):
+        out = {}  # type: ignore
+        for key, val in value.items():
+            if not isinstance(key, str):
+                raise NotImplementedError(f"key {key} should be a string")
+            out[key] = format_value(val)[0]  # type: ignore
+        quote_mark = False
+    else:
+        out = value
+    return out, quote_mark
+
+
+def format_repr(value: Optional[Any], quote_mark: bool = True) -> str:
     """
-    Format a string for the __repr__ method depending on its value.
+    Format strings for the __repr__ method.
 
-    :param field: str, the value of the field in __repr__
     :param value: string or None
     :param quote_mark: True to put quote marks around strings
     :return: a string
     """
-    if not isinstance(field, str):
-        raise TypeError(f"'field should be a string, got {type(field)}'")
     if isinstance(value, str) and quote_mark:
-        return f'{field}="{value}", '.replace("\\", "/")
-    return f"{field}={value}, ".replace("\\", "/")
+        return f'"{value}", '.replace("\\", "/")
+    return f"{value}, ".replace("\\", "/")
 
 
 def function_lmfit(params, x_axis, distribution, iterator=0):
@@ -1591,13 +1665,19 @@ def line(x_array, a, b):
     return a * x_array + b
 
 
-def pad_from_roi(arrays, roi, binning, pad_value=0, **kwargs):
+def pad_from_roi(
+    arrays: Union[np.ndarray, Tuple[np.ndarray, ...]],
+    roi: List[int],
+    binning: Tuple[int, int],
+    pad_value: Union[float, Tuple[float, ...]] = 0.0,
+    **kwargs,
+) -> Union[np.ndarray, Tuple[np.ndarray, ...]]:
     """
     Pad a 3D stack of frames provided a region of interest.
 
     The stacking is assumed to be on the first axis.
 
-    :param arrays: a 3D array of a sequence of 3D arrays of the same shape
+    :param arrays: a 3D array or a sequence of 3D arrays of the same shape
     :param roi: the desired region of interest of the unbinned frame. For an array in
      arrays, the shape is (nz, ny, nx), and roi corresponds to [y0, y1, x0, x1]
     :param binning: tuple of two integers (binning along Y, binning along X)
@@ -1608,7 +1688,7 @@ def pad_from_roi(arrays, roi, binning, pad_value=0, **kwargs):
     :return: an array (if a single array was provided) or a tuple of arrays interpolated
      on an orthogonal grid (same length as the number of input arrays)
     """
-    logger = kwargs.get("logger", module_logger)
+    logger: Logger = kwargs.get("logger", module_logger)
     ####################
     # check parameters #
     ####################
@@ -1628,7 +1708,7 @@ def pad_from_roi(arrays, roi, binning, pad_value=0, **kwargs):
         length=2,
         name="binning",
     )
-    if isinstance(pad_value, Real):
+    if isinstance(pad_value, float):
         pad_value = (pad_value,) * nb_arrays
     valid.valid_container(
         pad_value,
@@ -1676,8 +1756,8 @@ def pad_from_roi(arrays, roi, binning, pad_value=0, **kwargs):
             output_arrays.append(array)
 
         if nb_arrays == 1:
-            output_arrays = output_arrays[0]  # return the array instead of the tuple
-        return output_arrays
+            return np.asarray(output_arrays[0])  # return the array instead of the tuple
+        return tuple(output_arrays)
     return arrays
 
 
